%{
  POTENZA DISPERSA IMPIANTO RADIANTE A PAVIMENTO.

%% DATI RICHIESTI

% 1. Temperatura ingresso acqua e salto termico acqua (twe-twu) [°C]
twe 
dtw

% 2. Temperatura aria locale sopra- e sotto-stante [°C] ed adduttanza
% superficiale pavimento soprastante [W/mq K]
tao 
tal  
alph = 10.8;  % QUESTO VALORE E' STANDARD

% 3. Caratteristiche del tubo: diametro esterno De [mm], spessore parete st
%    [mm], conducibilità termica materiale tubo lambdat [W/m K]
De      
st      
lambdat 

% 3b. Rugosità interna tubo, coeff. Hazen-Williams
C 

% 4. Caratteristiche del massetto: spessore sm [m], copnducibilità termica
% lambdam [W/m K]
sm      
lambdam 

% 5. Resistenza termica del pavimento [mq K /W]
Rp 

% 6. Interasse tubi [m]
I 

% 7. Superficie coperta in pianta [mq]
S 

% 7b.  lunghezza di adduzione (andata e ritorno) fra il collettore e il pannello, m 
La 

% 8. Temperatura massima ammissibile sopra pavimento [°C]
%    29°C in ambienti dove ci si sofferma in permanenza,
%    33°C in locali bagno, docce e piscine,
%    35°C in zone perimetrali o in locali dove si accede raramente.
tpmax 

% 9. Resistenza termica sotto tubo (include anche lo spessore del massetto
% fino alla generatrice SUPERIORE del tubo): RS [mq K /W]
RS

% 10. Velocità minima accettabile per il fluido termovettore. Valori
inferiori non sono accettabili in quanto potrebbero comportare il ristagno
di bolle di aria. Valori maggiori sono richiesti qulor si realizzino tratti
in contropendenza
velw_min

% 11. Correggere dati di input non accettabili (correct = 1) ovvero
terminare simulazione (correct = 0)?
correct

% 12. Terminare la simulazione se dati non accettabili e "correct == 0" (0/1)?
terminate

%% Dati e correlazioni pre-impostati

% 1. Densità acqua
rhow      = @(t) 0.14395./(0.0112.^(1+(1-(t+273.15)./649.727).^0.05107));

%% ****************************************
%% Esempio di generazione dati di input
%% ****************************************
  clear all; close all; clc;
  tab_in.twe = 45;
  tab_in.dtw = 5;
  tab_in.tao  = 20;
  tab_in.tal  = 20;
  tab_in.alph = 10.8;
  tab_in.De      = 17;
  tab_in.st      = 2;
  tab_in.lambdat = 0.22;
  tab_in.C       = 0.01;
  tab_in.sm      = 0.20;
  tab_in.lambdam = 1.6; % Massetto a base di anidrite, lambda = 1.6 -- 1.9  W/m K
  tab_in.Rp = 0.05;      % Non dovrebbe essere superiore a 0.15 mq K /W
  tab_in.I = 0.05;
  tab_in.S = 30;
  tab_in.La = 3;
  tab_in.tpmax = 29;
  tab_in.RS = 2.6;
  tab_in.rhow      = @(t) 0.14395./(0.0112.^(1+(1-(t+273.15)./649.727).^0.05107));
  tab_in.velw_min = 0.1;
  tab_in.correct = 0;
  tab_in.terminate = 0;

  tab_out = potenza_pannelli_radianti(tab_in); tab_out.fo
%}
function tab_out = potenza_pannelli_radianti(tab_in)


%% FATTORI CALCOLATI

% 1. Fattore relativo alla resistenza termica del pavimento [-]
sm0      = 0.045; % [m]
lambdam0 = 1.0;   % [W/mq K]
tab_out.Fp = ((1/tab_in.alph)+(sm0/lambdam0))/((1/tab_in.alph)+(sm0/tab_in.lambdam)+tab_in.Rp);

% 2. Fattore relativo al interasse tra i tubi  [-]
if (tab_in.I<0.05)
    if tab_in.correct
        disp(['Interasse troppo modesto: aumentato al valore minimo pari a 50 mm']);
        tab_in.I = 0.05;
        tab_in.correctI = 1;
    else
        
        tab_in.correctI = -1;
        if tab_in.terminate, disp(['Interasse troppo modesto: simulazione terminata']);return; end
    end
end
if (tab_in.I<=0.375)
    x  = 1-tab_in.I/0.075;
    AI = interp1([0 0.05 0.1 0.15],[1.23 1.188 1.156 1.134],tab_in.Rp);
    tab_out.FI = AI^x;
else
    I0 = 0.375;
    x  = 1-I0/0.075;
    AI = interp1([0 0.05 0.1 0.15],[1.23 1.188 1.156 1.134],tab_in.Rp);
    tab_out.FI = (AI^x)*(0.375/tab_in.I);
end

% Salvare eventuale aggiornamento del interasse
tab_out.I = tab_in.I;


% 3. Fattore relativo allo spessore del massetto SOPRA (!!) i tubi [-]
if (tab_in.sm<0.015)
    if tab_in.correct
        disp(['Spessore massetto sopra tubi troppo modesto: aumentato al valore minimo pari a 15 mm']);
        tab_in.sm = 0.015;
        tab_out.sm = tab_in.sm;
        tab_in.correctsm = 1;
    else
        
        tab_in.correctsm = -1;
        if tab_in.terminate, disp(['Spessore massetto sopra tubi troppo modesto: simulazione terminata']);return; end
    end
end
T3.I = [0.05 0.075 0.1 0.15 0.2 0.225 0.3 0.375];
T3.Rp = [0 0.05 0.1 0.15];
T3.Am = [1.0690 1.056 1.0430 1.0370
    1.0660 1.053 1.0410 1.0350
    1.0630 1.050 1.0390 1.0335
    1.0570 1.046 1.0350 1.0305
    1.0510 1.041 1.0315 1.0275
    1.0480 1.038 1.0295 1.0260
    1.0395 1.031 1.0240 1.0210
    1.0300 1.024 1.0180 1.0160];
Am = interp2(T3.Rp,T3.I,T3.Am,tab_in.Rp,tab_in.I);
y = 100*(0.045-tab_in.sm);
tab_out.Fm = Am^y;

% 4. Fattore relativo al diametro esterno dei tubi [-]
if tab_in.correct
    if (tab_in.De<10)
        disp(['Diametro esterno tubo troppo modesto: aumentato al valore minimo pari a 10 mm']);
        tab_in.De = 10;
    elseif (tab_in.De>30)
        disp(['Diametro esterno tubo troppo elevato: ridotto al valore massimo pari a 30 mm']);
        tab_in.De = 30;
    end
    tab_in.correctDe = 1;
else
    
    tab_in.correctDe = -1;
    if tab_in.terminate, disp(['Diametro esterno tubo inadeguato: simulazione terminata']);return; end
end

tab_out.De = tab_in.De;

T4.I = [0.05 0.075 0.1 0.15 0.2 0.225 0.3 0.375];
T4.Rp = [0 0.05 0.1 0.15];
T4.AD = [1.013 1.013 1.012 1.011
    1.021 1.019 1.016 1.014
    1.029 1.025 1.022 1.018
    1.040 1.034 1.029 1.024
    1.046 1.040 1.035 1.030
    1.049 1.043 1.038 1.033
    1.053 1.049 1.044 1.039
    1.056 1.051 1.046 1.042];
AD = interp2(T4.Rp,T4.I,T4.AD,tab_in.Rp,tab_in.I);
z = 250*(tab_in.De/1000-0.02);
tab_out.FD = AD^z;

% 5. Fattore relativo alle caratteristiche del tubo B [W/mq K]
B0       = 6.7; % [W/mq K]
st0      = 0.002; % [m]
lambdat0 = 0.350; % [W/m k]

tab_out.B = 1/(1/B0 + (1.1/pi)*tab_out.Fp*tab_out.FI*tab_out.Fm*tab_out.FD*tab_in.I*...
    ((0.5/tab_in.lambdat)*log(tab_in.De/(tab_in.De-2*tab_in.st))-(0.5/lambdat0)*log(tab_in.De/(tab_in.De-2*st0))));

% 6. Temperatura uscita acqua twu [°C]
tab_out.twu = tab_in.twe-tab_in.dtw;
% Check su tuw: non deve essere inferiore alla temperatura ambiente
% superiore, altrimenti il pannello è sovradimensionato
if tab_in.correct
    if (tab_out.twu <= tab_in.tao)
        disp(['Temperatura ritorno acqua ',num2str(tab_out.twu),'°C inferiore a temperatura ambiente superiore ',num2str(tab_in.tao,2),'°C :\n salto termico lato acqua ridotto a twe-tao+1°C = ',num2str(tab_in.twe-tab_in.tao+1,2),'°C']);
        tab_in.dtw = tab_in.twe-tab_in.tao+1;
        tab_out.twu = tab_in.twe-tab_in.dtw;
        if (tab_in.dtw<0)
            disp(['Temperatura mandata acqua troppo bassa dopo correzione: ridefinizione di twe e dtw in funzione di tao']);
            tab_out.twu = tab_in.tao+1;
            tab_in.dtw = 7;
            tab_in.twe = twu+tab_in.dtw;
            tab_in.correcttwe = 1;
        end
        tab_out.dtw = tab_in.dtw;
        tab_out.twe = tab_in.twe;
    end
    tab_in.correctdtw = 1;
else
    
    tab_in.correctdtw = -1;
    if tab_in.terminate, disp(['Temperatura ritorno acqua inadeguata: simulazione terminata']);return; end
end


% 7. Flusso termico erogato verso l'alto [W/mq]
DTLM = tab_in.dtw/log((tab_in.twe-tab_in.tao)/(tab_out.twu-tab_in.tao));
tab_out.fo = DTLM*tab_out.B*tab_out.Fp*tab_out.FI*tab_out.Fm*tab_out.FD;

% 7b. Potenza termica erogata verso l'alto [W]
tab_out.qo = tab_out.fo*tab_in.S;

% 8. Potenza complessivamente erogata da pannello [W]
tab_out.qtot = tab_out.qo*(1+((1/tab_in.alph)+tab_in.Rp+tab_in.sm/tab_in.lambdam)/tab_in.RS+tab_in.S*(tab_in.tao-tab_in.tal)/(tab_in.RS*tab_out.qo));

% 9. Temperatura superficiale del pavimento
tab_out.tp =  tab_in.tao + (tab_out.fo/8.92)^(1/1.1);

if (tab_out.tp>tab_in.tpmax)
    disp(['WARNING: Temperatura superficiale del pavimento ',num2str(tab_out.tp,2),'°C superiore al massimo consentito ',num2str(tab_in.tpmax,2),'°C']);
end

% 10. Flusso termico massimo consentito verso l'alto [W/mq]
tab_out.fomax = 8.92*(tab_in.tpmax-tab_in.tao)^1.1;

% 11. Portata acqua [kg/s]
[~,hwe] = hwater(tab_in.twe);
[~,hwu] = hwater(tab_out.twu);
tab_out.mw = tab_out.qtot/(hwe-hwu);

% 12. Portata volumetrica acqua gw [mc/s] e gwlpm [LPM]
tab_out.gw = tab_out.mw/tab_in.rhow(tab_in.twe-0.5*tab_in.dtw);
tab_out.gwlpm = tab_out.gw*60000;


% 14. Lunghezza circuito senza tubazione collegamento [m]
tab_out.L = tab_in.S/tab_in.I;
% Lunghezza totale circuito
tab_out.Ltot = tab_in.La + tab_out.L;

% Numero tubi
tab_out.Npipes = ceil(tab_out.Ltot/110);
% Lunghezza singolo circuito, compresa adduzione
tab_out.Ltot_1 = tab_in.La + tab_out.L/tab_out.Npipes;
% Portata attraverso singolo tubo
tab_out.gw_1 = tab_out.gw/tab_out.Npipes;
tab_out.gwlpm_1 = tab_out.gwlpm/tab_out.Npipes;
tab_out.mw_1 = tab_out.mw/tab_out.Npipes;
% Calcolo della perdita di carico (attraverso ciascun tubo)

% 13. Velocità media acqua nel tubo [m/s]
tab_out.velw = tab_out.gw_1/(0.25*pi*(0.001*(tab_in.De-2*tab_in.st))^2);

% Controllo su velocità
if tab_out.velw<tab_in.velw_min
    disp(['La velocità dell''acqua nei tubi è inferiore\n al valore minimo ammissible: ', num2str(tab_out.velw,2), ' < ', num2str(tab_in.velw_min,2)]);
end


% 15. Perdita di carico continua (jw: perdita lineare [mmca/m]; dhc: perdita [mmca]) attraverso pannello
rhow      = @(t) 0.14395./(0.0112.^(1+(1-(t+273.15)./649.727).^0.05107));
muw       = @(t) exp(-3.79418+604.129./(139.18+t)).*0.001;
tab_out.rhow = rhow(tab_in.twe-tab_in.dtw*0.5);
tab_out.muw = muw(tab_in.twe-tab_in.dtw*0.5);

Reynolds  = tab_out.velw*0.001*(tab_in.De-tab_in.st*2)*tab_out.rhow/tab_out.muw;
eD        = tab_in.C/(tab_in.De-tab_in.st*2);
f         = moody_calc(Reynolds,eD);
tab_out.jw = 1000*(0.5*(tab_out.velw^2)/9.80665)*f/(0.001*(tab_in.De-tab_in.st*2));  % [mm.c.a./m]
tab_out.f = f;
tab_out.Re = Reynolds;
tab_out.eD = eD;
%%%%(tab_out.velw/(0.849*tab_in.C*(0.001*(tab_in.De-2*tab_in.st)*0.5)^0.63))^(1/0.54);
tab_out.dhc = tab_out.jw*tab_out.Ltot_1;  % [mm.c.a.]

% 16. Perdite di carico localizzate, la cui entità dipende dal numero di
% curve realizzate. Qui vengono stimate pari al 30% delle perdite continue.
% Valori usuali in generee si attestano sul 20% - 30% delle perdite
% continue.
tab_out.dhloc = 0.3*tab_out.dhc;  % [mm.c.a.]

% 17. Perdite di carico totali [mm.c.a.]
tab_out.dhtot = tab_out.dhc + tab_out.dhloc;  % [mm.c.a.]

clc;
disp(['NUMERO PANNELLI: ',num2str(tab_out.Npipes)])
disp(['LUNGHEZZA TOTALE TUBO SINGOLO PANNELLO: ',num2str(tab_out.Ltot_1,4),' metri'])
disp(['PERDITA DI CARICO TOTALE SINGOLO PANNELLO: ',num2str(tab_out.dhtot,4),' mm.c.a.'])
disp(['PORTATA ACQUA SINGOLO CIRCUITO: ',num2str(tab_out.gwlpm_1,4),' l.p.m.'])
disp(['VELOCITA'' ACQUA: ',num2str(tab_out.velw,2),' m/s'])
disp(['POTENZA TERMICA EROGATA COMPLESSIVAMENTE: ',num2str(tab_out.qtot,4),' Watt'])
disp(['POTENZA TERMICA EROGATA VERSO L''AMBIENTE RISCALDATO: ',num2str(tab_out.qo,4),' Watt'])
disp(['FLUSSO TERMICO EROGATA VERSO L''AMBIENTE RISCALDATO: ',num2str(tab_out.fo,4),' Watt/m^2'])
disp(['POTENZA TERMICA EROGATA COMPLESSIVAMENTE, PER METRO DI TUBO (ESCLUSO COLLEGAMENTO): ',num2str(tab_out.qtot/tab_out.L),' Watt/m'])
disp(['POTENZA TERMICA EROGATA VERSO L''AMBIENTE RISCALDATO, PER METRO DI TUBO (ESCLUSO COLLEGAMENTO): ',num2str(tab_out.qo/tab_out.L),' Watt/m'])
disp(['TEMPERATURA SUPERFICIALE PAVIMENTO: ',num2str(tab_out.tp,3),' °C'])
disp(['TEMPERATURA MANDATA ACQUA: ',num2str(tab_in.twe,3),' °C'])
disp(['TEMPERATURA RITORNO ACQUA: ',num2str(tab_out.twu,3),' °C'])
disp(['DIFFERENZA DI TEMPERATURA MEDIA LOGARITMICA: ',num2str((tab_in.twe-tab_out.twu)/log((tab_in.twe-tab_in.tao)/(tab_out.twu-tab_in.tao)),3),' °C'])

return

end